#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['leppard']

package_data = \
{'': ['*']}

extras_require = \
{'dev': ['black==19.10b0', 'flake8==3.8.1', 'isort==4.3.21']}

setup(name='leppard',
      version='0.1.0',
      description='Pour some sugar on the cli',
      author='Harrison Pim',
      author_email=None,
      url='https://github.com/harrisonpim/leppard',
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
     )



"""
Pour some sugar on the cli
"""

__version__ = "0.1.0"


def leppard():
    return """
    ;                            ,                                                                                                 ;           
    ED.                          Et                                                                                                ED.         
    E#Wi                  ,;     E#t                                       ,;                                                      E#Wi        
    E###G.              f#i      E##t                        i           f#i   t           t                          j.           E###G.      
    E#fD#W;           .E#t       E#W#t                      LE         .E#t    ED.         ED.                    ..  EW,          E#fD#W;     
    E#t t##L         i#W,        E#tfL.                    L#E        i#W,     E#K:        E#K:                  ;W,  E##j         E#t t##L    
    E#t  .E#K,      L#D.         E#t                      G#W.       L#D.      E##W;       E##W;                j##,  E###D.       E#t  .E#K,  
    E#t    j##f   :K#Wfff;    ,ffW#Dffj.                 D#K.      :K#Wfff;    E#E##t      E#E##t              G###,  E#jG#W;      E#t    j##f 
    E#t    :E#K:  i##WLLLLt    ;LW#ELLLf.               E#K.       i##WLLLLt   E#ti##f     E#ti##f           :E####,  E#t t##f     E#t    :E#K:
    E#t   t##L     .E#L          E#t                  .E#E.         .E#L       E#t ;##D.   E#t ;##D.        ;W#DG##,  E#t  :K#E:   E#t   t##L  
    E#t .D#W;        f#E:        E#t                 .K#E             f#E:     E#ELLE##K:  E#ELLE##K:      j###DW##,  E#KDDDD###i  E#t .D#W;   
    E#tiW#G.          ,WW;       E#t                .K#D               ,WW;    E#L;;;;;;,  E#L;;;;;;,     G##i,,G##,  E#f,t#Wi,,,  E#tiW#G.    
    E#K##i             .D#;      E#t               .W#G                 .D#;   E#t         E#t          :K#K:   L##,  E#t  ;#W:    E#K##i      
    E##D.                tt      E#t              :W##########Wt          tt   E#t         E#t         ;##D.    L##,  DWi   ,KK:   E##D.       
    E#t                          ;#t              :,,,,,,,,,,,,,.                                      ,,,      .,,                E#t         
    L:                            :;                                                                                               L:      
    """


def leppard_print():
    print(leppard())


leppard_print()
